@@ -15,24 +15,22 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id:$ *)
-
 (** Parser for DOT file format *)
 
 open Dot_ast
 
 let parse_dot_ast_from_chan c =
   let lb = Lexing.from_channel c in
-  let dot = 
+  let dot =
     try
-      Dot_parser.file Dot_lexer.token lb 
+      Dot_parser.file Dot_lexer.token lb
     with Parsing.Parse_error ->
       let n = Lexing.lexeme_start lb in
       failwith (Printf.sprintf "Dot.parse: parse error character %d" n)
   in
   close_in c;
   dot
-    
+
 let parse_dot_ast f =
   let c = open_in f in
   parse_dot_ast_from_chan c
@@ -45,18 +43,23 @@ let get_string = function
   | Number s -> s
   | Html s -> s
 
-module Parse 
+module Parse
   (B : Builder.S)
-  (L : sig 
+  (L : sig
      val node : node_id -> attr list -> B.G.V.label
        (** how to build the node label out of the set of attributes *)
-     val edge : attr list -> B.G.E.label 
+     val edge : attr list -> B.G.E.label
        (** how to build the edge label out of the set of attributes *)
    end) =
 struct
 
   module Attr = struct
-    module M = Map.Make(struct type t = id let compare = compare end)
+    module M = 
+      Map.Make
+        (struct
+           type t = id
+           let compare : t -> t -> int = Pervasives.compare
+         end)
     type t = id option M.t
     let empty = M.empty
     let add = List.fold_left (fun a (x,v) -> M.add x v a)
@@ -70,7 +73,7 @@ struct
     (* collect node attributes *)
     let def_node_attr = ref Attr.empty in
     let node_attr = Hashtbl.create 97 in
-    
+
     (* collect cluster attributes *)
     let def_clust_attr = ref Attr.empty in
     let clust_attr = Hashtbl.create 97 in
@@ -82,7 +85,7 @@ struct
       let l = try Hashtbl.find node_attr id
               with Not_found -> !def_node_attr in
       Hashtbl.replace node_attr id (Attr.addl l al) in
-    
+
     let add_clust_attr id_opt al =
       match id_opt with
 	| Some id ->
@@ -91,12 +94,12 @@ struct
                     with Not_found -> !def_clust_attr in
 	    Hashtbl.replace clust_attr s (Attr.addl l al)
 	| _ -> () in
-    
+
     let add_clust_node id_cluster id_node =
       let id_nodes = try Hashtbl.find clust_nodes id_cluster
       with Not_found -> [] in
       Hashtbl.add clust_nodes id_cluster (id_node :: id_nodes) in
-    
+
     let rec collect_node_attr cluster_op stmts =
       List.iter (
         function
@@ -107,7 +110,7 @@ struct
 		| _ -> ()
 	      end
           | Attr_node al -> def_node_attr := Attr.addl !def_node_attr al
-          | Edge_stmt (NodeId id, nl, _) -> 
+          | Edge_stmt (NodeId id, nl, _) ->
               add_node_attr id [];
               List.iter (function | NodeId id -> add_node_attr id []
 			          | _ -> ()) nl
@@ -146,14 +149,14 @@ struct
                let g,vn = node g id [] in
                  List.fold_left
                    (fun g m -> match m with
-                      | NodeId idm -> 
+                      | NodeId idm ->
                           let g,vm = node g idm [] in
                           let e = B.G.E.create vn el vm in
                             B.add_edge_e g e
-                      | NodeSub _ -> 
+                      | NodeSub _ ->
                           g)
                    g nl
-           | Attr_edge al -> 
+           | Attr_edge al ->
                def_edge_attr := Attr.addl !def_edge_attr al; g
            | Subgraph (SubgraphDef (_, stmts)) ->
                add_stmts g stmts
@@ -167,7 +170,7 @@ struct
       let h = Hashtbl.create 30 in
       Hashtbl.iter (fun k a -> Hashtbl.add h k [Attr.list a]) clust_attr;
       h in
-    
+
     graph, clusters_hash
 
   let get_graph_bb stmts =
@@ -183,9 +186,9 @@ struct
 
   let parse_dot_from_chan c =
     let lb = Lexing.from_channel c in
-    let dot = 
+    let dot =
       try
-	Dot_parser.file Dot_lexer.token lb 
+	Dot_parser.file Dot_lexer.token lb
       with Parsing.Parse_error ->
 	let n = Lexing.lexeme_start lb in
 	failwith (Printf.sprintf "Dot.parse: parse error character %d" n)
@@ -200,7 +203,7 @@ struct
   let parse f =
     fst (create_graph_and_clusters (parse_dot f))
 
-  let parse_with_bb_from_chan c =    
+  let parse_with_bb_from_chan c =
     let dot = parse_dot_from_chan c in
     create_graph_and_clusters dot, get_graph_bb dot.stmts
 
@@ -212,4 +215,5 @@ struct
 	  graph, bounding_box, clusters
       | None ->
 	  failwith "Cannot read bounding box in xdot file"
+
 end
