@@ -15,8 +15,6 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: oper.ml,v 1.13 2005-06-30 10:48:55 filliatr Exp $ *)
-
 (* Basic operations over graphs *)
 
 module type S = sig
@@ -41,25 +39,25 @@ module Make(B : Builder.S) = struct
     let phi v g =
       let g = if reflexive then B.add_edge g v v else g in
       G.fold_succ
-	(fun sv g -> G.fold_pred (fun pv g -> B.add_edge g pv sv) g v g) 
+	(fun sv g -> G.fold_pred (fun pv g -> B.add_edge g pv sv) g v g)
 	g v g
     in
     G.fold_vertex phi g0 g0
 
-  let transitive_closure ?(reflexive=false) g0 = 
+  let transitive_closure ?(reflexive=false) g0 =
     add_transitive_closure ~reflexive (B.copy g0)
 
   module H = Hashtbl.Make(G.V)
 
   let mirror g =
     if G.is_directed then begin
-      let g' = 
+      let g' =
 	G.fold_vertex
 	  (fun v g' -> B.add_vertex g' v)
 	  g (B.empty ())
       in
       G.fold_edges_e
-	(fun e g' -> 
+	(fun e g' ->
 	   let v1 = G.E.src e in
 	   let v2 = G.E.dst e in
 	   B.add_edge_e g' (G.E.create v2 (G.E.label e) v1))
@@ -77,27 +75,27 @@ module Make(B : Builder.S) = struct
 	 g g')
       g (B.empty ())
 
-  let intersect g1 g2 = 
+  let intersect g1 g2 =
     G.fold_vertex
       (fun v g ->
 	 try
 	   let succ = G.succ_e g2 v in
-	   G.fold_succ_e 
-	     (fun e g -> 
-		if List.mem e succ 
-		then B.add_edge_e g e 
-		else g)
+	   G.fold_succ_e
+	     (fun e g ->
+	       if List.exists (fun e' -> G.E.compare e e' = 0) succ
+	       then B.add_edge_e g e
+	       else g)
 	     g1 v (B.add_vertex g v)
-	 with Invalid_argument _ -> 
-	   (* $v \notin g2$ *)
+	 with Invalid_argument _ ->
+	   (* [v] not in [g2] *)
 	   g)
       g1 (B.empty ())
 
   let union g1 g2 =
-    let add g1 g2 = 
+    let add g1 g2 =
       (* add the graph [g1] in [g2] *)
-      G.fold_vertex 
-	(fun v g -> 
+      G.fold_vertex
+	(fun v g ->
 	   G.fold_succ_e (fun e g -> B.add_edge_e g e) g1 v (B.add_vertex g v))
 	g1 g2
     in
@@ -109,16 +107,16 @@ module P(G : Sig.P) = Make(Builder.P(G))
 module I(G : Sig.I) = Make(Builder.I(G))
 
 module Choose(G : sig
-		type t 
-		type vertex 
-		type edge 
+		type t
+		type vertex
+		type edge
 		val iter_vertex : (vertex -> unit) -> t -> unit
 		val iter_edges_e : (edge -> unit) -> t -> unit
 	      end) =
 struct
 
   exception Found_Vertex of G.vertex
-  let choose_vertex g = 
+  let choose_vertex g =
     try
       G.iter_vertex (fun v -> raise (Found_Vertex v)) g;
       invalid_arg "choose_vertex"
@@ -135,8 +133,8 @@ struct
 
 end
 
-module Neighbourhood(G : sig 
-		      type t 
+module Neighbourhood(G : sig
+		      type t
 		      module V : Sig.COMPARABLE
 		      val fold_succ: (V.t -> 'a -> 'a) -> t -> V.t -> 'a -> 'a
 		      val succ: t -> V.t -> V.t list
@@ -146,9 +144,9 @@ struct
   module Vertex_Set = Set.Make(G.V)
 
   let set_from_vertex g v =
-    G.fold_succ 
-      (fun v' s -> if G.V.equal v v' then s else Vertex_Set.add v' s) 
-      g v Vertex_Set.empty 
+    G.fold_succ
+      (fun v' s -> if G.V.equal v v' then s else Vertex_Set.add v' s)
+      g v Vertex_Set.empty
 
   let list_from_vertex g v =
     let rec aux = function
@@ -165,8 +163,8 @@ struct
   let set_from_vertices g l =
     let fold_left f = List.fold_left f Vertex_Set.empty l in
     let env_init = fold_left (fun s v -> Vertex_Set.add v s) in
-    let add x s = 
-      if Vertex_Set.mem x env_init then s else Vertex_Set.add x s 
+    let add x s =
+      if Vertex_Set.mem x env_init then s else Vertex_Set.add x s
     in
     fold_left (fun s v -> G.fold_succ add g v s)
 
